/*
 * File         : BV_Msg_Header.h
 * Author       : Tomasz Stachowiak
 * Created      : Wed May 20 19:23:51 1998
 * Revision     : $Revision$
 * Updated      : $Date$
 * Copyright: Northeast Parallel Architectures Center
 *            at Syracuse University 1998
 */

#ifndef __BV_MSG_HEADER_H
#define __BV_MSG_HEADER_H

#include <BVN/BVN.h>
#include <BVN/SOCK_Stream.h>

#include "BV.h"

typedef enum _msg_tags
{
  /* remote requests */
  reqRemoteSessionAccept,
  reqRemoteSessionQuit,
  reqRemoteSessionReject,
  reqRemoteSessionAddMember,
  reqRemoteSessionAddRest,
  reqRemoteSessionSendToApp,
  reqRemoteSessionSendAppData,
  reqRemoteSessionStartApp,

  /* remote acknowledgments */
  ackRemoteInvitationReceived,

  reqAppData = 51,
  indAppData,

  reqNewLocalSessionInit = 60,
  reqNewRemoteSessionConnect,
  reqNewRemoteSessionInvite,
} Msg_Tags;

class BV_Msg_Header
{
  
#define MSG_HEADER_LENGTH 56
  
 public:

  
  BV_Msg_Header();

  int recv(SOCK_Stream *stream);
  int send(SOCK_Stream *stream);

  unsigned char get_tag();
  unsigned char get_session();
  void get_sender(Participant *part); 
  void get_receiver(Participant *part); 
  int get_size();

  void set_tag(unsigned char tag);
  void set_session(unsigned char session);
  void set_sender(Participant *part); 
  void set_sender_id(unsigned char id); 
  void set_receiver(Participant *part);
  void set_size(int size);
  
 private:
  
  unsigned char tag_;
  unsigned char session_;
  Participant sender_;
  Participant receiver_;
  int size_;
  char buffer_[MSG_HEADER_LENGTH];
  
};


#endif

